summaryrefslogtreecommitdiffstats
path: root/web/gui/dashboard/dashboard.js
diff options
context:
space:
mode:
Diffstat (limited to 'web/gui/dashboard/dashboard.js')
-rw-r--r--web/gui/dashboard/dashboard.js6
1 files changed, 3 insertions, 3 deletions
diff --git a/web/gui/dashboard/dashboard.js b/web/gui/dashboard/dashboard.js
index b9d96d5c..83f7b584 100644
--- a/web/gui/dashboard/dashboard.js
+++ b/web/gui/dashboard/dashboard.js
@@ -63,7 +63,7 @@
* (default: null) */
/*global netdataAlarmsRecipients *//* array, an array of alarm recipients to show notifications for
* (default: null) */
-/*global netdataAlarmsRemember *//* boolen, keep our position in the alarm log at browser local storage
+/*global netdataAlarmsRemember *//* boolean, keep our position in the alarm log at browser local storage
* (default: true) */
/*global netdataAlarmsActiveCallback *//* function, a hook for the alarm logs
* (default: undefined) */
@@ -6618,7 +6618,7 @@ let chartState = function (element) {
if (NETDATA.options.current.show_help) {
if (this.element_legend_childs.toolbox !== null) {
if (this.debug) {
- this.log('hideChart(): hidding legend popovers');
+ this.log('hideChart(): hiding legend popovers');
}
$(this.element_legend_childs.toolbox_left).popover('hide');
@@ -8165,7 +8165,7 @@ let chartState = function (element) {
}
}
// create a hidden div to be used for hidding
// the original legend of the chart library
let el = document.createElement('div');
if (this.element_legend !== null) {
@@ -8165,7 +8165,7 @@ let chartState = function (element) {
}
}
- // create a hidden div to be used for hidding
+ // create a hidden div to be used for hiding
// the original legend of the chart library
let el = document.createElement('div');